OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bokmärken",
    "Failed to import one bookmark, because: " : "Misslyckades att importera bokmärken eftersom:",
    "No file provided for import" : "Inga filer given för importering",
    "Unsupported file type for import" : "Ogiltig filtyp för import",
    "Add a Bookmark" : "Lägg till ett bokmärke",
    "Add folder" : "Lägg till mapp",
    "Select" : "Välj",
    "Deselect" : "Välj inte",
    "Details" : "Detaljer",
    "Delete" : "Radera",
    "Saved" : "Sparad",
    "Tags" : "Taggar",
    "Description" : "Beskrivning",
    "No bookmarks here." : "Inga bokmärken här.",
    "Favorites" : "Favoriter",
    "Settings" : "Inställningar",
    "Add to {instanceName} " : "Lägg till {instanceName} ",
    "Recently added" : "Nyligen tillagd",
    "Most visited" : "Mest besökta",
    "RSS Feed" : "RSS-flöde",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Ta bort alla bokmärken permanent från ditt konto. Det går inte att ångra!",
    "Delete all bookmarks" : "Ta bort alla bokmärken",
    "Open details" : "Öppna detaljer",
    "An error occurred while trying to save the bookmark." : "Ett fel uppstod när bokmärket skulle sparas.",
    "Error" : "Fel",
    "Uncategorized" : "Okategoriserad",
    "Import completed successfully." : "Importen slutfördes utan problem.",
    "Do you really want to delete all your bookmarks?" : "Vill du verkligen radera alla dina bokmärken?",
    "Set tags" : "Ange taggar",
    "A Bookmark manager for Nextcloud" : "En bokmärkeshanterare för Nextcloud",
    "Add a bookmark" : "Lägg till ett bokmärke",
    "This URL is already bookmarked! Overwrite?" : "Den här webbadressen är redan bokmärkt! Skriva över?",
    "The title of the page" : "Sidans titel",
    "The address of the page" : "Sidans adress",
    "Description of the page" : "Sidans beskrivning",
    "Save" : "Spara",
    "Previews" : "Förhandsvisningar",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "För att kunna visa riktiga skärmdumpar av dina bokmärkta webbplatser kan bokmärken använda en tredjepartstjänst för att generera dom.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Du kan antingen registrera dig gratis hos <a href=\"http://screeenly.com\">screeenly.com</a> eller <a href=\"https://github.com/stefanzweifel/screeenly\">sätta upp din egen server</a>.",
    "Bookmarks feed" : "Bokmärkesflöde"
},
"nplurals=2; plural=(n != 1);");
